function value = AIRead(this, channel)
%AIREAD Read analog input channels.
%   VALUE = AIREAD(DEVICE, CHANNEL) reads a value from analog input
%   channel CHANNEL. CHANNEL may be a scalar or a vector, in which case
%   multiple channels are read. Channels are numbered from 1.
%
%   Example - read the first analog input channel of MF624 board
%     dev = HudaqDevice('MF624');
%     AIRead(dev, 1)
%     Close(dev);
%
%   See also HUDAQDEVICE, AOWRITE.

%   Copyright 2002-2007 HUMUSOFT s.r.o.


% validate device handle
hudaqhandle('Validate', this.H);

% read multiple channels
if numel(channel)>1
  [result, dummy, value] = hudaqcall('HudaqAIReadMultiple', this.H, numel(channel), int32(channel)-1);
  if ~strcmp(result, 'HUDAQSUCCESS')
    error('HUDAQLIB:AICannotRead', 'Cannot read analog input channels %s.', mat2str(channel));
  end

% read single channel
else
  value = hudaqcall('HudaqAIRead', this.H, int32(channel)-1);
end
