function AOWrite(this, channel, value)
%AOWRITE Write analog output channels.
%   AOWRITE(DEVICE, CHANNEL, VALUE) writes VALUE to analog output
%   channel CHANNEL. Channels are numbered from 1.
%   CHANNEL may be a vector, in which case VALUE must be either a
%   vector with the same number of elements or a scalar that is written to
%   all the channels.
%
%   Example - write 2.5V to the first analog output channel of MF624 board
%     dev = HudaqDevice('MF624');
%     AOWrite(dev, 1, 2.5)
%     Close(dev);
%
%   See also HUDAQDEVICE, AIREAD.

%   Copyright 2002-2007 HUMUSOFT s.r.o.


% validate device handle
hudaqhandle('Validate', this.H);

% write multiple channels
if numel(channel)>1
  value = expandarg(value, channel);
  result = hudaqcall('HudaqAOWriteMultiple', this.H, numel(channel), int32(channel)-1, double(value));  
  if ~strcmp(result, 'HUDAQSUCCESS')
    error('HUDAQLIB:AOCannotWrite', 'Cannot write analog output channels %s.', mat2str(channel));
  end

% write single channel
else
  hudaqcall('HudaqAOWrite', this.H, int32(channel)-1, value);
end
