function value = DIReadBit(this, channel, bit)
%DIREADBIT Read individual bits of digital input channel.
%   VALUE = DIREADBIT(DEVICE, CHANNEL, BIT) reads a bit BIT from
%   digital input channel CHANNEL. BIT may be a scalar or a vector, in which
%   case multiple bits are read. Channels and bits are numbered from 1.
%
%   Example - read the third bit of the first digital input channel
%     dev = HudaqDevice('MF624');
%     DIReadBit(dev, 1, 3)
%     Close(dev);
%
%   See also HUDAQDEVICE, DIREAD, DOWRITEBIT.

%   Copyright 2002-2007 HUMUSOFT s.r.o.


% validate device handle
hudaqhandle('Validate', this.H);

% read multiple bits
if numel(bit)>1
  value = hudaqcall('HudaqDIRead', this.H, int32(channel)-1);
  value = logical(bitand(bitshift(value, 1-double(uint32(bit))), 1));

% read single bit
else
  value = hudaqcall('HudaqDIReadBit', this.H, int32(channel)-1, bit-1);
end
