function DOWrite(this, channel, value)
%DOWRITE Write digital output channels.
%   DOWRITE(DEVICE, CHANNEL, VALUE) writes VALUE to digital output
%   channel CHANNEL. Channels are numbered from 1.
%   CHANNEL may be a vector, in which case VALUE must be either a
%   vector with the same number of elements or a scalar that is written to
%   all the channels.
%
%   Example - write 64 to the first digital output channel of MF624 board
%     dev = HudaqDevice('MF624');
%     DOWrite(dev, 1, 64)
%     Close(dev);
%
%   See also HUDAQDEVICE, DOWRITEBIT, DIREAD.

%   Copyright 2002-2007 HUMUSOFT s.r.o.


% validate device handle
hudaqhandle('Validate', this.H);

% write multiple channels
if numel(channel)>1
  value = expandarg(value, channel);  
  result = hudaqcall('HudaqDOWriteMultiple', this.H, numel(channel), int32(channel)-1, int32(value));
  if ~strcmp(result, 'HUDAQSUCCESS')
    error('HUDAQLIB:DOCannotWrite', 'Cannot write values to digital output channels %s', mat2str(channel));
  end

% write single channel
else
  hudaqcall('HudaqDOWrite', this.H, int32(channel)-1, value);
end

