function PWMWrite(this, channel, frequency, duty)
%PWMWRITE Generate pulse-width modulation signal on counter output.
%   PWMWRITE(DEVICE, CHANNEL, FREQUENCY, DUTY) generates pulse-width
%   modulation signal on counter output channel CHANNEL, where FREQUENCY
%   is frequency in Hz and DUTY is the fraction of signal period during which
%   the signal is at high level.
%
%   Example - generate symmetric signal with frequency of 1kHz of the first
%             counter output channel of MF624 board:
%     dev = HudaqDevice('MF624');
%     PWMWrite(dev, 1, 1000, 0.5)
%     Close(dev);
%
%   See also HUDAQDEVICE.

%   Copyright 2002-2007 HUMUSOFT s.r.o.


% validate device handle
hudaqhandle('Validate', this.H);

% check and scalar-expand the arguments
frequency = expandarg(frequency, channel);
duty = expandarg(duty, channel);

% generate PWM outputs
for i=1:numel(channel)
  res = hudaqcall('HudaqPWMWrite', this.H, int32(channel(i))-1, frequency(i), duty(i));
  if ~strcmp(res, 'HUDAQSUCCESS')
    error('HUDAQLIB:PWMCannotWrite', 'Cannot write values to PWM output, channel %s', mat2str(channel));
  end
end
