function SetParameter(this, channel, param, value)
%SETPARAMETER Set configuration parameter of a channel.
%   SETPARAMETER(DEVICE, CHANNEL, PARAM, VALUE) sets parameter PARAM
%   of channel CHANNEL to VALUE. Parameter names and their values
%   are documented in product documentation.
%
%   Example - turn on filter on first encoder input channel:
%     dev = HudaqDevice('MF624');
%     SetParameter(dev, 1, 'HudaqEncFILTER', 1)
%     Close(dev);
%
%   See also GETPARAMETER, HUDAQDEVICE.

%   Copyright 2002-2007 HUMUSOFT s.r.o.


% validate device handle
hudaqhandle('Validate', this.H);

% set parameters in a loop
for i=1:numel(channel)
  val = extractparam(value, i);
  if ischar(val)
    val = translatesymbol(this, val);
    if ischar(val)       % failed to translate valuex
      error('HUDAQLIB:CannotSetParameter','Cannot set parameter: %s; channel: %s; value: %s ', num2str(param), num2str(channel), num2str(value));
    end
  end  
  result = hudaqcall('HudaqSetParameter', this.H, int32(channel(i))-1, extractparam(param, i), val);

  % Emit error when error occured.
  if ~strcmp(result,'HUDAQSUCCESS')
    error('HUDAQLIB:CannotSetParameter','Cannot set parameter: %s; channel: %s; value: %s ', num2str(param), num2str(channel), num2str(value));
  end
  
end  
